#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              2.2.0.0
visibility:           public
id:                   lsp-2.2.0.0-IyBcprRCQKO7ojGpw20jEQ
key:                  lsp-2.2.0.0-IyBcprRCQKO7ojGpw20jEQ
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  f5cc752b2ed91c64628bab78d9ba6c0e
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Logging,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.2.0-FNxMpKzUXQFCYQeu6dmY3Q:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Lens from lsp-types-2.0.2.0-FNxMpKzUXQFCYQeu6dmY3Q:Language.LSP.Protocol.Lens,
    Language.LSP.Protocol.Message from lsp-types-2.0.2.0-FNxMpKzUXQFCYQeu6dmY3Q:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.2.0-FNxMpKzUXQFCYQeu6dmY3Q:Language.LSP.Protocol.Types,
    Language.LSP.Server, Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Control Language.LSP.Server.Core
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp
hs-libraries:         HSlsp-2.2.0.0-IyBcprRCQKO7ojGpw20jEQ
depends:
    aeson-2.2.2.0-1j2UQRt1mV1Loqrh8KvmRL
    async-2.2.6-9S5YBpAZQ2fGtiHAvRKHi7
    attoparsec-0.14.4-L7yQnQokRKL4IK7J2HszTx base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.6-D87yZYcUfEep9NLn4SFvW
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-H7NkROSKCrjFQZGpvHIgO1
    lens-5.3.4-B9QPRzrMZ8J355CXfNFvnN
    lens-aeson-1.2.3-8AxkfttKsiDFqtddrrQehV
    lsp-types-2.0.2.0-FNxMpKzUXQFCYQeu6dmY3Q mtl-2.3.1
    prettyprinter-1.7.1-SaqeLf0VF75CcRG6tvr9r
    random-1.2.1.3-EZAJJDcAdrKCzLsP4iSxFh
    row-types-1.0.1.2-8UtqxaozlYp4RcQR3tmfvC
    sorted-list-0.2.3.1-23YGAprarO5AJhoczm2jF3 stm-2.5.1.0
    temporary-1.3-9rcNesEzN8L9Jsn9e228tO text-2.0.2
    text-rope-0.3-2uUblqklLbMABDnE4Bf4VV transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-2pZfUb3hQF1KSawFItMd4V
    uuid-1.3.16.1-B8dHM40up0W32eC5wrEUud

haddock-interfaces:   /usr/share/doc/haskell-lsp/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

